@@ -25,6 +25,7 @@
 #include "menu.h"
 #include "lineseq.h"
 
+
 // When defined draws AI 'planning'
 //#define AI_PLANNING_DEBUG	1
 
@@ -39,6 +40,7 @@ PLAYER::PLAYER (GLOBALDATA *global, ENVIRONMENT *env)
 	tank = NULL;
 	_turnStage = 0;
 	selected = FALSE;
+        changed_weapon = false;
 
 	_targetMatrix = new double[global->screenWidth];
 
@@ -613,7 +615,7 @@ int PLAYER::chooseItemToBuy ()
 	for (int count = 0; count < THINGS; count++) {
 		int currItem = selectRandomItem ();
 		int itemNum = currItem - WEAPONS;
-		char cumulative;
+		int cumulative;
 
 		//is item available for purchase or selected first item
 		//first item is free
@@ -714,7 +716,7 @@ int PLAYER::traceShellTrajectory (TANK *ctank, int *estimateX, int *estimateY, d
 	TANK *ltank;
 	int hitSomething = 0;
 	double distance;
-	char direction = (char)copysign (1, xv);
+	int direction = (char)copysign (1, xv);
 	double drag;
 	int ticks = 0;
 	int maxTicks = 500;
@@ -1009,12 +1011,12 @@ int PLAYER::addTankDamageToMatrix (TANK *ctank, TANK *ltank, int weapNum)
 		if (weapNum >= RIOT_CHARGE && weapNum <= RIOT_BLAST) {
 			// add points only within range and above ctank
 			if (	(cy > ctank->y - (radius / 2)) ||
-				(abs (ctank->x - cx) > radius))
+				(fabs (ctank->x - cx) > radius))
 				continue;
 		} else if (weapNum >= SML_ROLLER && weapNum <= DTH_ROLLER) {
 			// Only aim rollers above other tanks
 			if (cy > tankY + TANKHEIGHT &&
-				abs (ctank->x - cx) > radius)
+				fabs (ctank->x - cx) > radius)
 				continue;
 		} else if (weapNum >= SML_LAZER && weapNum <= LRG_LAZER) {
 			// Lazer can only be aimed above horizontal
@@ -1085,7 +1087,7 @@ void PLAYER::calcDamageMatrix (TANK *ctank, int weapNum)
 			if (itemNum  >= ITEM_VENGEANCE && itemNum <= ITEM_FATAL_FURY) {
 				// add sqrt distances for each tank * potential damage
 				long int totalEffectiveDamage = calcTotalEffectiveDamage (itemNum);
-				_targetMatrix[(int)ctank->x] += sqrt (abs (ctank->x - ltank->x)) * totalEffectiveDamage;
+				_targetMatrix[(int)ctank->x] += sqrt (fabs (ctank->x - ltank->x)) * totalEffectiveDamage;
 
 			}
 		}
